@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2021 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -483,17 +483,17 @@ void GuidedMissileStrategy::radarRender() const
         dir[2] = vel[2] * d * shotTailLength * length;
         glBegin(GL_LINES);
         glVertex2fv(orig);
-        if (BZDB.eval("leadingShotLine") == 1)   //leading
+        if (BZDBCache::leadingShotLine == 1)   //leading
         {
             glVertex2f(orig[0] + dir[0], orig[1] + dir[1]);
             glEnd();
         }
-        else if (BZDB.eval("leadingShotLine") == 0)     //lagging
+        else if (BZDBCache::leadingShotLine == 0)     //lagging
         {
             glVertex2f(orig[0] - dir[0], orig[1] - dir[1]);
             glEnd();
         }
-        else if (BZDB.eval("leadingShotLine") == 2)     //both
+        else if (BZDBCache::leadingShotLine == 2)     //both
         {
             glVertex2f(orig[0] + dir[0], orig[1] + dir[1]);
             glEnd();
