@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2021 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -66,7 +66,7 @@ public:
         idleStats,
         info,
         kick,
-        kill,
+        kill_,
         lagStats,
         lagwarn,
         jitterwarn,
