@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2021 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -1440,7 +1440,7 @@ public:
 
         if (data->Body.size())
         {
-            pageBuffer += TextUtils::format("Content-Length: %d\n", data->Body.size());
+            pageBuffer += TextUtils::format("Content-Length: %zu\n", data->Body.size());
 
             pageBuffer += "Content-Type: ";
             if (Response.ReturnCode == e200OK)
