@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2021 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -11,8 +11,8 @@
  */
 
 
+// Interface header
 #include "bzfio.h"
-#include "common.h"
 
 #include <stdarg.h>
 /* system implementation headers */
@@ -31,6 +31,9 @@
 #  include <mmsystem.h>
 #endif
 
+// Common header
+#include "TimeKeeper.h"
+
 LoggingCallback *loggingCallback = NULL;
 
 static bool doTimestamp = false;
@@ -51,33 +54,23 @@ static const int tsBufferSize = 512;
 
 static char *timestamp(char *buf, bool micros, bool utc)
 {
-    struct tm *tm;
+    int year, month, day, hour, min, sec;
+    long tv_usec;
+    long *usecP;
     if (micros)
-    {
-#if !defined(_WIN32)
-        struct timeval tv;
-        gettimeofday (&tv, NULL);
-        if (utc)
-            tm = gmtime((const time_t *)&tv.tv_sec);
-        else
-            tm = localtime((const time_t *)&tv.tv_sec);
-        snprintf (buf, tsBufferSize, "%04d-%02d-%02d %02d:%02d:%02ld.%06ld: ", tm->tm_year+1900,
-                  tm->tm_mon+1,
-                  tm->tm_mday, tm->tm_hour, tm->tm_min, (long)tm->tm_sec, (long)tv.tv_usec );
-#endif
-    }
+        usecP = &tv_usec;
     else
-    {
-        time_t tt;
-        time (&tt);
-        if (utc)
-            tm = gmtime (&tt);
-        else
-            tm = localtime (&tt);
-
-        snprintf (buf, tsBufferSize, "%04d-%02d-%02d %02d:%02d:%02d: ", tm->tm_year+1900, tm->tm_mon+1,
-                  tm->tm_mday, tm->tm_hour, tm->tm_min, tm->tm_sec );
-    }
+        usecP = nullptr;
+    if (utc)
+        TimeKeeper::UTCTime(&year, &month, &day, nullptr, &hour, &min, &sec, nullptr, usecP);
+    else
+        TimeKeeper::localTime(&year, &month, &day, &hour, &min, &sec, nullptr, usecP);
+    if (micros)
+        snprintf (buf, tsBufferSize, "%04d-%02d-%02d %02d:%02d:%02d.%06ld: ", year,
+                  month, day, hour, min, sec, tv_usec);
+    else
+        snprintf (buf, tsBufferSize, "%04d-%02d-%02d %02d:%02d:%02d: ", year, month,
+                  day, hour, min, sec);
     return buf;
 }
 
