@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2021 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -226,6 +226,11 @@ void MeshFragSceneNode::Geometry::setStyle(int style_)
     style = style_;
 }
 
+const GLfloat* MeshFragSceneNode::Geometry::getPosition() const
+{
+    return sceneNode.getSphere();
+}
+
 //
 // MeshFragSceneNode
 //
